import logging
logger = logging.getLogger(__name__)
logger.info("Loaded " + __name__)

import os
import operator

from eazyserver.rpc.meta import __list_methods

from flask import Blueprint, jsonify, Response, make_response, request, \
    current_app as app

jsonrpc_bp = Blueprint('eazy_jsonrpc_routes', __name__)

@jsonrpc_bp.route('/' + app.config["API_VERSION"] + '/' + app.config["RPC_BASE_ROUTE"] + '/' + app.config["RPC_ROUTE_NAME"], methods=['POST'])
def rpc():
    req = request.get_data().decode()
    response = app.methods.dispatch(req)
    return Response(str(response), response.http_status,
        mimetype='application/json')

@jsonrpc_bp.route('/' + app.config["API_VERSION"] + '/' + app.config["RPC_BASE_ROUTE"] + '/' + app.config["RPC_ROUTE_NAME"], methods=['GET'])
def list_aggregates():
    response = {
        "methods": __list_methods()
    }
    return jsonify(response)




import logging
logger = logging.getLogger(__name__)
logger.info("Loaded " + __name__)

class FunctionMapper():
    def __init__(self):
        self.routes = {}

    def add(self, route_str):
        def decorator(f):
            self.routes[route_str] = f
            return f

        return decorator

    def get(self, path):
        view_function = self.routes.get(path)
        if view_function:
            return view_function
        else:
            raise ValueError('Route "{}"" has not been registered'.format(path))

    def _routes(self):
        return self.routes.keys()



import logging
logger = logging.getLogger(__name__)
logger.info("Loaded " + __name__)

# from ..core.function_mapper import FunctionMapper 
# mongo_pipelines = FunctionMapper()

from function_mapper import *
from utils import *
from influxdb_connector import *